@@ -1,29 +1,27 @@
 #include <stdio.h>
 #include <stdarg.h>
 
-#include "debug.h"
-#include "options.h"
-#include "output.h"
+#include "common.h"
 
 void
-debug_(int level, const char *file, int line, const char *func,
-		const char *fmt, ...)
-{
+debug_(int level, const char *file, int line, const char *fmt, ...) {
 	char buf[1024];
 	va_list args;
 
-	if (opt_d < level) {
+	if (!(options.debug & level)) {
 		return;
 	}
 	va_start(args, fmt);
 	vsnprintf(buf, 1024, fmt, args);
 	va_end(args);
 
-	output_line(NULL, "DEBUG: %s:%d: %s(): %s", file, line, func, buf);
+	output_line(NULL, "DEBUG: %s:%d: %s", file, line, buf);
 }
 
-// The following section provides a way to print things, like hex dumps,
-// with out using buffered output.  This was written by Steve Munroe of IBM.
+/*
+ * The following section provides a way to print things, like hex dumps,
+ * with out using buffered output.  This was written by Steve Munroe of IBM.
+ */
 
 #include <stdio.h>
 #include <errno.h>
@@ -31,8 +29,8 @@ debug_(int level, const char *file, int line, const char *func,
 #include <stdlib.h>
 #include <sys/ptrace.h>
 
-static int xwritehexl(long i)
-{
+static int
+xwritehexl(long i) {
 	int rc = 0;
 	char text[17];
 	int j;
@@ -52,8 +50,8 @@ static int xwritehexl(long i)
 	return rc;
 }
 
-static int xwritec(char c)
-{
+static int
+xwritec(char c) {
 	char temp = c;
 	char *text = &temp;
 	int rc = 0;
@@ -61,13 +59,13 @@ static int xwritec(char c)
 	return rc;
 }
 
-static int xwritecr(void)
-{
+static int
+xwritecr(void) {
 	return xwritec('\n');
 }
 
-static int xwritedump(void *ptr, long addr, int len)
-{
+static int
+xwritedump(void *ptr, long addr, int len) {
 	int rc = 0;
 	long *tprt = (long *)ptr;
 	int i;
@@ -84,13 +82,21 @@ static int xwritedump(void *ptr, long addr, int len)
 	return rc;
 }
 
-int xinfdump(long pid, void *ptr, int len)
-{
+int
+xinfdump(long pid, void *ptr, int len) {
 	int rc;
 	int i;
-	long wrdcnt = len / sizeof(long) + 1;
-	long *infwords = malloc(wrdcnt * sizeof(long));
-	long addr = (long)ptr;
+	long wrdcnt;
+	long *infwords;
+	long addr;
+
+	wrdcnt = len / sizeof(long) + 1;
+	infwords = malloc(wrdcnt * sizeof(long));
+	if (!infwords) {
+		perror("ltrace: malloc");
+		exit(1);
+	}
+	addr = (long)ptr;
 
 	addr = ((addr + sizeof(long) - 1) / sizeof(long)) * sizeof(long);
 
