@@ -1,31 +1,27 @@
-#if HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
 
-#include "options.h"
-#include "output.h"
-#include "demangle.h"
-
-#include "dict.h"
+#include "common.h"
 
 #ifdef USE_DEMANGLE
 
 /*****************************************************************************/
 
-static struct dict *d = NULL;
+static Dict *d = NULL;
 
-const char *my_demangle(const char *function_name)
-{
+const char *
+my_demangle(const char *function_name) {
 	const char *tmp, *fn_copy;
 #if !defined HAVE_LIBIBERTY && defined HAVE_LIBSUPC__
 	extern char *__cxa_demangle(const char *, char *, size_t *, int *);
 	int status = 0;
 #endif
 
+	debug(DEBUG_FUNCTION, "my_demangle(name=%s)", function_name);
+
 	if (!d)
 		d = dict_init(dict_key2hash_string, dict_key_cmp_string);
 
