@@ -1,6 +1,4 @@
-#if HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 extern char *cplus_demangle(const char *mangled, int options);
 
