@@ -2,14 +2,14 @@
   Dictionary based on code by Morten Eriksen <mortene@sim.no>.
 */
 
-struct dict;
+typedef struct dict Dict;
 
-extern struct dict *dict_init(unsigned int (*key2hash) (void *),
+extern Dict *dict_init(unsigned int (*key2hash) (void *),
 			      int (*key_cmp) (void *, void *));
-extern void dict_clear(struct dict *d);
-extern int dict_enter(struct dict *d, void *key, void *value);
-extern void *dict_find_entry(struct dict *d, void *key);
-extern void dict_apply_to_all(struct dict *d,
+extern void dict_clear(Dict *d);
+extern int dict_enter(Dict *d, void *key, void *value);
+extern void *dict_find_entry(Dict *d, void *key);
+extern void dict_apply_to_all(Dict *d,
 			      void (*func) (void *key, void *value, void *data),
 			      void *data);
 
@@ -17,3 +17,4 @@ extern unsigned int dict_key2hash_string(void *key);
 extern int dict_key_cmp_string(void *key1, void *key2);
 extern unsigned int dict_key2hash_int(void *key);
 extern int dict_key_cmp_int(void *key1, void *key2);
+extern Dict * dict_clone(Dict *old, void * (*key_clone)(void*), void * (*value_clone)(void*));
