@@ -1,6 +1,4 @@
-#if HAVE_CONFIG_H
 # include "config.h"
-#endif
 
 #include <endian.h>
 #include <errno.h>
@@ -12,10 +10,7 @@
 #include <string.h>
 #include <unistd.h>
 
-#include "ltrace.h"
-#include "elf.h"
-#include "debug.h"
-#include "options.h"
+#include "common.h"
 
 static void do_init_elf(struct ltelf *lte, const char *filename);
 static void do_close_elf(struct ltelf *lte);
@@ -23,18 +18,19 @@ static void add_library_symbol(GElf_Addr addr, const char *name,
 			       struct library_symbol **library_symbolspp,
 			       enum toplt type_of_plt, int is_weak);
 static int in_load_libraries(const char *name, struct ltelf *lte);
-static GElf_Addr opd2addr(struct ltelf *ltc, void *addr);
+static GElf_Addr opd2addr(struct ltelf *ltc, GElf_Addr addr);
 
 #ifdef PLT_REINITALISATION_BP
 extern char *PLTs_initialized_by_here;
 #endif
 
-static void do_init_elf(struct ltelf *lte, const char *filename)
-{
+static void
+do_init_elf(struct ltelf *lte, const char *filename) {
 	int i;
 	GElf_Addr relplt_addr = 0;
 	size_t relplt_size = 0;
 
+	debug(DEBUG_FUNCTION, "do_init_elf(filename=%s)", filename);
 	debug(1, "Reading ELF from %s...", filename);
 
 	memset(lte, 0, sizeof(*lte));
@@ -159,7 +155,33 @@ static void do_init_elf(struct ltelf *lte, const char *filename)
 					error(EXIT_FAILURE, 0,
 					      "Couldn't get .dynamic data from \"%s\"",
 					      filename);
+#ifdef __mips__
+/**
+  MIPS ABI Supplement:
 
+  DT_PLTGOT This member holds the address of the .got section.
+
+  DT_MIPS_SYMTABNO This member holds the number of entries in the
+  .dynsym section.
+
+  DT_MIPS_LOCAL_GOTNO This member holds the number of local global
+  offset table entries.
+
+  DT_MIPS_GOTSYM This member holds the index of the first dyamic
+  symbol table entry that corresponds to an entry in the gobal offset
+  table.
+
+ */
+				if(dyn.d_tag==DT_PLTGOT){
+					lte->pltgot_addr=dyn.d_un.d_ptr;
+				}
+				if(dyn.d_tag==DT_MIPS_LOCAL_GOTNO){
+					lte->mips_local_gotno=dyn.d_un.d_val;
+				}
+				if(dyn.d_tag==DT_MIPS_GOTSYM){
+					lte->mips_gotsym=dyn.d_un.d_val;
+				}
+#endif // __mips__
 				if (dyn.d_tag == DT_JMPREL)
 					relplt_addr = dyn.d_un.d_ptr;
 				else if (dyn.d_tag == DT_PLTRELSZ)
@@ -169,6 +191,8 @@ static void do_init_elf(struct ltelf *lte, const char *filename)
 			Elf_Data *data;
 			size_t j;
 
+			lte->hash_type = SHT_HASH;
+
 			data = elf_getdata(scn, NULL);
 			if (data == NULL || elf_getdata(scn, data) != NULL
 			    || data->d_off || data->d_size != shdr.sh_size)
@@ -209,6 +233,27 @@ static void do_init_elf(struct ltelf *lte, const char *filename)
 				error(EXIT_FAILURE, 0,
 				      "Unknown .hash sh_entsize in \"%s\"",
 				      filename);
+		} else if (shdr.sh_type == SHT_GNU_HASH
+			   && lte->hash == NULL) {
+			Elf_Data *data;
+
+			lte->hash_type = SHT_GNU_HASH;
+
+			if (shdr.sh_entsize != 0
+			    && shdr.sh_entsize != 4) {
+				error(EXIT_FAILURE, 0,
+				      ".gnu.hash sh_entsize in \"%s\" should be 4, but is %llu",
+				      filename, shdr.sh_entsize);
+			}
+
+			data = elf_getdata(scn, NULL);
+			if (data == NULL || elf_getdata(scn, data) != NULL
+			    || data->d_off || data->d_size != shdr.sh_size)
+				error(EXIT_FAILURE, 0,
+				      "Couldn't get .gnu.hash data from \"%s\"",
+				      filename);
+
+			lte->hash = (Elf32_Word *) data->d_buf;
 		} else if (shdr.sh_type == SHT_PROGBITS
 			   || shdr.sh_type == SHT_NOBITS) {
 			if (strcmp(name, ".plt") == 0) {
@@ -217,11 +262,14 @@ static void do_init_elf(struct ltelf *lte, const char *filename)
 				if (shdr.sh_flags & SHF_EXECINSTR) {
 					lte->lte_flags |= LTE_PLT_EXECUTABLE;
 				}
-			} else if (strcmp(name, ".opd") == 0) {
+			}
+#ifdef ARCH_SUPPORTS_OPD
+			else if (strcmp(name, ".opd") == 0) {
 				lte->opd_addr = (GElf_Addr *) (long) shdr.sh_addr;
 				lte->opd_size = shdr.sh_size;
 				lte->opd = elf_rawdata(scn, NULL);
 			}
+#endif
 		}
 	}
 
@@ -266,8 +314,9 @@ static void do_init_elf(struct ltelf *lte, const char *filename)
 	}
 }
 
-static void do_close_elf(struct ltelf *lte)
-{
+static void
+do_close_elf(struct ltelf *lte) {
+	debug(DEBUG_FUNCTION, "do_close_elf()");
 	if (lte->lte_flags & LTE_HASH_MALLOCED)
 		free((char *)lte->hash);
 	elf_end(lte->elf);
@@ -277,9 +326,11 @@ static void do_close_elf(struct ltelf *lte)
 static void
 add_library_symbol(GElf_Addr addr, const char *name,
 		   struct library_symbol **library_symbolspp,
-		   enum toplt type_of_plt, int is_weak)
-{
+		   enum toplt type_of_plt, int is_weak) {
 	struct library_symbol *s;
+
+	debug(DEBUG_FUNCTION, "add_library_symbol()");
+
 	s = malloc(sizeof(struct library_symbol) + strlen(name) + 1);
 	if (s == NULL)
 		error(EXIT_FAILURE, errno, "add_library_symbol failed");
@@ -289,7 +340,6 @@ add_library_symbol(GElf_Addr addr, const char *name,
 	s->plt_type = type_of_plt;
 	s->next = *library_symbolspp;
 	s->enter_addr = (void *)(uintptr_t) addr;
-	s->brkpnt = NULL;
 	s->name = (char *)(s + 1);
 	strcpy(s->name, name);
 	*library_symbolspp = s;
@@ -297,77 +347,151 @@ add_library_symbol(GElf_Addr addr, const char *name,
 	debug(2, "addr: %p, symbol: \"%s\"", (void *)(uintptr_t) addr, name);
 }
 
-static int in_load_libraries(const char *name, struct ltelf *lte)
-{
+/* stolen from elfutils-0.123 */
+static unsigned long
+private_elf_gnu_hash(const char *name) {
+	unsigned long h = 5381;
+	const unsigned char *string = (const unsigned char *)name;
+	unsigned char c;
+	for (c = *string; c; c = *++string)
+		h = h * 33 + c;
+	return h & 0xffffffff;
+}
+
+static int
+in_load_libraries(const char *name, struct ltelf *lte) {
 	size_t i;
 	unsigned long hash;
+	unsigned long gnu_hash;
 
 	if (!library_num)
 		return 1;
 
 	hash = elf_hash((const unsigned char *)name);
+	gnu_hash = private_elf_gnu_hash(name);
 	for (i = 1; i <= library_num; ++i) {
-		Elf32_Word nbuckets, symndx;
-		Elf32_Word *buckets, *chain;
-
 		if (lte[i].hash == NULL)
 			continue;
 
-		nbuckets = lte[i].hash[0];
-		buckets = &lte[i].hash[2];
-		chain = &lte[i].hash[2 + nbuckets];
-		for (symndx = buckets[hash % nbuckets];
-		     symndx != STN_UNDEF; symndx = chain[symndx]) {
-			GElf_Sym sym;
+		if (lte[i].hash_type == SHT_GNU_HASH) {
+			Elf32_Word * hashbase = lte[i].hash;
+			Elf32_Word nbuckets = *hashbase++;
+			Elf32_Word symbias = *hashbase++;
+			Elf32_Word bitmask_nwords = *hashbase++;
+			Elf32_Word * buckets;
+			Elf32_Word * chain_zero;
+			Elf32_Word bucket;
 
-			if (gelf_getsym(lte[i].dynsym, symndx, &sym) == NULL)
-				error(EXIT_FAILURE, 0,
-				      "Couldn't get symbol from .dynsym");
+			// +1 for skipped `shift'
+			hashbase += lte[i].ehdr.e_ident[EI_CLASS] * bitmask_nwords + 1;
+			buckets = hashbase;
+			hashbase += nbuckets;
+			chain_zero = hashbase - symbias;
+			bucket = buckets[gnu_hash % nbuckets];
 
-			if (sym.st_value != 0
-			    && sym.st_shndx != SHN_UNDEF
-			    && strcmp(name, lte[i].dynstr + sym.st_name) == 0)
-				return 1;
+			if (bucket != 0) {
+				const Elf32_Word *hasharr = &chain_zero[bucket];
+				do
+					if ((*hasharr & ~1u) == (gnu_hash & ~1u)) {
+						int symidx = hasharr - chain_zero;
+						GElf_Sym sym;
+
+						if (gelf_getsym(lte[i].dynsym, symidx, &sym) == NULL)
+							error(EXIT_FAILURE, 0,
+							      "Couldn't get symbol from .dynsym");
+
+						if (sym.st_value != 0
+						    && sym.st_shndx != SHN_UNDEF
+						    && strcmp(name, lte[i].dynstr + sym.st_name) == 0)
+							return 1;
+					}
+				while ((*hasharr++ & 1u) == 0);
+			}
+		} else {
+			Elf32_Word nbuckets, symndx;
+			Elf32_Word *buckets, *chain;
+			nbuckets = lte[i].hash[0];
+			buckets = &lte[i].hash[2];
+			chain = &lte[i].hash[2 + nbuckets];
+
+			for (symndx = buckets[hash % nbuckets];
+			     symndx != STN_UNDEF; symndx = chain[symndx]) {
+				GElf_Sym sym;
+
+				if (gelf_getsym(lte[i].dynsym, symndx, &sym) == NULL)
+					error(EXIT_FAILURE, 0,
+					      "Couldn't get symbol from .dynsym");
+
+				if (sym.st_value != 0
+				    && sym.st_shndx != SHN_UNDEF
+				    && strcmp(name, lte[i].dynstr + sym.st_name) == 0)
+					return 1;
+			}
 		}
 	}
 	return 0;
 }
 
-static GElf_Addr opd2addr(struct ltelf *lte, void *addr)
-{
-	long base;
-	long offset;
-	GElf_Addr ret_val;
+static GElf_Addr
+opd2addr(struct ltelf *lte, GElf_Addr addr) {
+#ifdef ARCH_SUPPORTS_OPD
+	unsigned long base, offset;
 
 	if (!lte->opd)
-		return (GElf_Addr) (long) addr;
+		return addr;
 
-	base = (long)lte->opd->d_buf;
-	offset = (long)addr - (long)lte->opd_addr;
+	base = (unsigned long)lte->opd->d_buf;
+	offset = (unsigned long)addr - (unsigned long)lte->opd_addr;
 	if (offset > lte->opd_size)
 		error(EXIT_FAILURE, 0, "static plt not in .opd");
 
-	ret_val = (GElf_Addr) * (long *)(base + offset);
-	return ret_val;
+	return *(GElf_Addr*)(base + offset);
+#else //!ARCH_SUPPORTS_OPD
+	return addr;
+#endif
 }
 
-struct library_symbol *read_elf(struct process *proc)
-{
+struct library_symbol *
+read_elf(Process *proc) {
 	struct library_symbol *library_symbols = NULL;
-	struct ltelf lte[MAX_LIBRARY + 1];
+	struct ltelf lte[MAX_LIBRARIES + 1];
 	size_t i;
 	struct opt_x_t *xptr;
 	struct library_symbol **lib_tail = NULL;
-	struct opt_x_t *main_cheat;
 	int exit_out = 0;
 
+	debug(DEBUG_FUNCTION, "read_elf(file=%s)", proc->filename);
+
 	elf_version(EV_CURRENT);
 
 	do_init_elf(lte, proc->filename);
 	proc->e_machine = lte->ehdr.e_machine;
 	for (i = 0; i < library_num; ++i)
 		do_init_elf(&lte[i + 1], library[i]);
-
+#ifdef __mips__
+	// MIPS doesn't use the PLT and the GOT entries get changed
+	// on startup.
+	proc->need_to_reinitialize_breakpoints = 1;
+	for(i=lte->mips_gotsym; i<lte->dynsym_count;i++){
+		GElf_Sym sym;
+		const char *name;
+		GElf_Addr addr = arch_plt_sym_val(lte, i, 0);
+		if (gelf_getsym(lte->dynsym, i, &sym) == NULL){
+			error(EXIT_FAILURE, 0,
+					"Couldn't get relocation from \"%s\"",
+					proc->filename);
+		}
+		name=lte->dynstr+sym.st_name;
+		if(ELF64_ST_TYPE(sym.st_info) != STT_FUNC){
+			debug(2,"sym %s not a function",name);
+			continue;
+		}
+		add_library_symbol(addr, name, &library_symbols, 0,
+				ELF64_ST_BIND(sym.st_info) != 0);
+		if (!lib_tail)
+			lib_tail = &(library_symbols->next);
+	}
+#else
 	for (i = 0; i < lte->relplt_count; ++i) {
 		GElf_Rel rel;
 		GElf_Rela rela;
@@ -403,19 +527,21 @@ struct library_symbol *read_elf(struct process *proc)
 			add_library_symbol(addr, name, &library_symbols,
 					   (PLTS_ARE_EXECUTABLE(lte)
 					   ?  LS_TOPLT_EXEC : LS_TOPLT_POINT),
-					   ELF64_ST_BIND(sym.st_info) != 0);
+					   ELF64_ST_BIND(sym.st_info) == STB_WEAK);
 			if (!lib_tail)
 				lib_tail = &(library_symbols->next);
 		}
 	}
-
+#endif // !__mips__
 #ifdef PLT_REINITALISATION_BP
+	struct opt_x_t *main_cheat;
+
 	if (proc->need_to_reinitialize_breakpoints) {
 		/* Add "PLTs_initialized_by_here" to opt_x list, if not
-                   already there. */
+		   already there. */
 		main_cheat = (struct opt_x_t *)malloc(sizeof(struct opt_x_t));
 		if (main_cheat == NULL)
-			error(EXIT_FAILURE, 0, "Couldn allocate memory");
+			error(EXIT_FAILURE, 0, "Couldn't allocate memory");
 		main_cheat->next = opt_x;
 		main_cheat->found = 0;
 		main_cheat->name = PLTs_initialized_by_here;
@@ -451,7 +577,7 @@ struct library_symbol *read_elf(struct process *proc)
 			if (xptr->name && strcmp(xptr->name, name) == 0) {
 				/* FIXME: Should be able to use &library_symbols as above.  But
 				   when you do, none of the real library symbols cause breaks. */
-				add_library_symbol(opd2addr(lte, (void*)addr),
+				add_library_symbol(opd2addr(lte, addr),
 						   name, lib_tail, LS_TOPLT_NONE, 0);
 				xptr->found = 1;
 				break;
@@ -464,8 +590,7 @@ struct library_symbol *read_elf(struct process *proc)
 			if (strcmp(xptr->name, PLTs_initialized_by_here) == 0) {
 				if (lte->ehdr.e_entry) {
 					add_library_symbol (
-						elf_plt2addr (lte, (void*)(long)
-							lte->ehdr.e_entry),
+						opd2addr (lte, lte->ehdr.e_entry),
 						PLTs_initialized_by_here,
 						lib_tail, 1, 0);
 					fprintf (stderr, "WARNING: Using e_ent"
