@@ -4,8 +4,6 @@
 #include <gelf.h>
 #include <stdlib.h>
 
-#include "ltrace.h"
-
 struct ltelf {
 	int fd;
 	Elf *elf;
@@ -39,9 +37,9 @@ struct ltelf {
 #define PLTS_ARE_EXECUTABLE(lte) ((lte->lte_flags & LTE_PLT_EXECUTABLE) != 0)
 
 extern int library_num;
-extern char *library[MAX_LIBRARY];
+extern char *library[MAX_LIBRARIES];
 
-extern struct library_symbol *read_elf(struct process *);
+extern struct library_symbol *read_elf(Process *);
 
 extern GElf_Addr arch_plt_sym_val(struct ltelf *, size_t, GElf_Rela *);
 
