@@ -1,6 +1,4 @@
-#if HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -12,17 +10,14 @@
 #include <pwd.h>
 #include <grp.h>
 
-#include "ltrace.h"
-#include "options.h"
-#include "debug.h"
-#include "sysdep.h"
+#include "common.h"
 
-static void change_uid(struct process *proc)
-{
+static void
+change_uid(Process *proc) {
 	uid_t run_uid, run_euid;
 	gid_t run_gid, run_egid;
 
-	if (opt_u) {
+	if (options.user) {
 		struct passwd *pent;
 
 		if (getuid() != 0 || geteuid() != 0) {
@@ -30,14 +25,14 @@ static void change_uid(struct process *proc)
 				"you must be root to use the -u option\n");
 			exit(1);
 		}
-		if ((pent = getpwnam(opt_u)) == NULL) {
-			fprintf(stderr, "cannot find user `%s'\n", opt_u);
+		if ((pent = getpwnam(options.user)) == NULL) {
+			fprintf(stderr, "cannot find user `%s'\n", options.user);
 			exit(1);
 		}
 		run_uid = pent->pw_uid;
 		run_gid = pent->pw_gid;
 
-		if (initgroups(opt_u, run_gid) < 0) {
+		if (initgroups(options.user, run_gid) < 0) {
 			perror("ltrace: initgroups");
 			exit(1);
 		}
@@ -45,7 +40,7 @@ static void change_uid(struct process *proc)
 		run_uid = getuid();
 		run_gid = getgid();
 	}
-	if (opt_u || !geteuid()) {
+	if (options.user || !geteuid()) {
 		struct stat statbuf;
 		run_euid = run_uid;
 		run_egid = run_gid;
@@ -69,8 +64,8 @@ static void change_uid(struct process *proc)
 	}
 }
 
-void execute_program(struct process *sp, char **argv)
-{
+void
+execute_program(Process *sp, char **argv) {
 	pid_t pid;
 
 	debug(1, "Executing `%s'...", sp->filename);
@@ -85,7 +80,7 @@ void execute_program(struct process *sp, char **argv)
 		execvp(sp->filename, argv);
 		fprintf(stderr, "Can't execute `%s': %s\n", sp->filename,
 			strerror(errno));
-		exit(1);
+		_exit(1);
 	}
 
 	debug(1, "PID=%d", pid);
