@@ -1,6 +1,4 @@
-#if HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <string.h>
 #include <stdlib.h>
@@ -8,14 +6,11 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <limits.h>
+#include <sys/ioctl.h>
 
-#if HAVE_GETOPT_H
 #include <getopt.h>
-#endif
 
-#include "ltrace.h"
-#include "options.h"
-#include "defs.h"
+#include "common.h"
 
 #ifndef SYSCONFDIR
 #define SYSCONFDIR "/etc"
@@ -24,29 +19,30 @@
 #define SYSTEM_CONFIG_FILE SYSCONFDIR "/ltrace.conf"
 #define USER_CONFIG_FILE "~/.ltrace.conf"
 
-#define MAX_LIBRARY		30
-char *library[MAX_LIBRARY];
+struct options_t options = {
+	.align    = DEFAULT_ALIGN,    /* alignment column for results */
+	.user     = NULL,             /* username to run command as */
+	.syscalls = 0,                /* display syscalls */
+	.libcalls = 1,                /* display library calls */
+#ifdef USE_DEMANGLE
+	.demangle = 0,                /* Demangle low-level symbol names */
+#endif
+	.indent = 0,                  /* indent output according to program flow */
+	.output = NULL,               /* output to a specific file */
+	.summary = 0,                 /* Report a summary on program exit */
+	.debug = 0,                   /* debug */
+	.arraylen = DEFAULT_ARRAYLEN, /* maximum # array elements to print */
+	.strlen = DEFAULT_STRLEN,     /* maximum # of bytes printed in strings */
+	.follow = 0,                  /* trace child processes */
+};
+
+char *library[MAX_LIBRARIES];
 int library_num = 0;
 static char *progname;		/* Program name (`ltrace') */
-FILE *output;
-int opt_a = DEFAULT_ACOLUMN;	/* alignment column for results */
-int opt_A = DEFAULT_ARRAYLEN;	/* maximum # array elements to print */
-int opt_c = 0;			/* Report a summary on program exit */
-int opt_d = 0;			/* debug */
 int opt_i = 0;			/* instruction pointer */
-int opt_s = DEFAULT_STRLEN;	/* maximum # of bytes printed in strings */
-int opt_S = 0;			/* display syscalls */
-int opt_L = 1;			/* display library calls */
-int opt_f = 0;			/* trace child processes as they are created */
-char *opt_u = NULL;		/* username to run command as */
 int opt_r = 0;			/* print relative timestamp */
 int opt_t = 0;			/* print absolute timestamp */
-#ifdef USE_DEMANGLE
-int opt_C = 0;			/* Demangle low-level symbol names */
-#endif
-int opt_n = 0;			/* indent output according to program flow */
 int opt_T = 0;			/* show the time spent inside each call */
-int opt_o = 0;			/* output to a specific file */
 
 /* List of pids given to option -p: */
 struct opt_p_t *opt_p = NULL;	/* attach to process with a given pid */
@@ -67,63 +63,33 @@ struct opt_F_t *opt_F = NULL;	/* alternate configuration file(s) */
 char *PLTs_initialized_by_here = PLT_REINITALISATION_BP;
 #endif
 
-static void usage(void)
-{
-#if !(HAVE_GETOPT || HAVE_GETOPT_LONG)
-	fprintf(stdout, "Usage: %s [command [arg ...]]\n"
-		"Trace library calls of a given program.\n\n", progname);
-#else
+static void
+err_usage(void) {
+	fprintf(stderr, "Try `%s --help' for more information\n", progname);
+	exit(1);
+}
+
+static void
+usage(void) {
 	fprintf(stdout, "Usage: %s [option ...] [command [arg ...]]\n"
 		"Trace library calls of a given program.\n\n"
-# if HAVE_GETOPT_LONG
 		"  -a, --align=COLUMN  align return values in a secific column.\n"
-# else
-		"  -a COLUMN           align return values in a secific column.\n"
-# endif
 		"  -A ARRAYLEN         maximum number of array elements to print.\n"
 		"  -c                  count time and calls, and report a summary on exit.\n"
 # ifdef USE_DEMANGLE
-#  if HAVE_GETOPT_LONG
 		"  -C, --demangle      decode low-level symbol names into user-level names.\n"
-#  else
-		"  -C                  decode low-level symbol names into user-level names.\n"
-#  endif
-# endif
-# if HAVE_GETOPT_LONG
-		"  -d, --debug         print debugging info.\n"
-# else
-		"  -d                  print debugging info.\n"
 # endif
+		"  -D, --debug=LEVEL   enable debugging (see -Dh or --debug=help).\n"
+		"  -Dh, --debug=help   show help on debugging.\n"
 		"  -e expr             modify which events to trace.\n"
-		"  -f                  follow forks.\n"
-# if HAVE_GETOPT_LONG
-		"  -F, --config=FILE   load alternate configuration file\n"
-# else
-		"  -F FILE             load alternate configuration file\n"
-# endif
-		"                      (can be repeated).\n"
-# if HAVE_GETOPT_LONG
+		"  -f                  trace children (fork() and clone()).\n"
+		"  -F, --config=FILE   load alternate configuration file (may be repeated).\n"
 		"  -h, --help          display this help and exit.\n"
-# else
-		"  -h                  display this help and exit.\n"
-# endif
 		"  -i                  print instruction pointer at time of library call.\n"
-#  if HAVE_GETOPT_LONG
 		"  -l, --library=FILE  print library calls from this library only.\n"
-#  else
-		"  -l FILE             print library calls from this library only.\n"
-#  endif
 		"  -L                  do NOT display library calls.\n"
-# if HAVE_GETOPT_LONG
 		"  -n, --indent=NR     indent output by NR spaces for each call level nesting.\n"
-# else
-		"  -n NR               indent output by NR spaces for each call level nesting.\n"
-# endif
-# if HAVE_GETOPT_LONG
 		"  -o, --output=FILE   write the trace output to that file.\n"
-# else
-		"  -o FILE             write the trace output to that file.\n"
-# endif
 		"  -p PID              attach to the process with the process ID pid.\n"
 		"  -r                  print relative timestamps.\n"
 		"  -s STRLEN           specify the maximum string size to print.\n"
@@ -131,22 +97,33 @@ static void usage(void)
 		"  -t, -tt, -ttt       print absolute timestamps.\n"
 		"  -T                  show the time spent inside each call.\n"
 		"  -u USERNAME         run command with the userid, groupid of username.\n"
-# if HAVE_GETOPT_LONG
 		"  -V, --version       output version information and exit.\n"
-# else
-		"  -V                  output version information and exit.\n"
-# endif
 		"  -x NAME             treat the global NAME like a library subroutine.\n"
 #ifdef PLT_REINITALISATION_BP
 		"  -X NAME             same as -x; and PLT's will be initialized by here.\n"
 #endif
 		"\nReport bugs to ltrace-devel@lists.alioth.debian.org\n",
 		progname);
-#endif
 }
 
-static char *search_for_command(char *filename)
-{
+static void
+usage_debug(void) {
+	fprintf(stdout, "%s debugging option, --debug=<octal> or -D<octal>:\n", progname);
+	fprintf(stdout, 
+			"\n"
+			" number  ref. in source   description\n"
+			"      1   general           Generally helpful progress information\n"
+			"     10   event             Shows every event received by a traced process\n"
+			"     20   process           Shows actions carried upon a traced processes\n"
+			"     40   function          Shows every entry to internal functions\n"
+			"\n"
+			"Debugging options are mixed using bitwise-or.\n"
+			"Note that the meanings and values are subject to change.\n"
+		   );
+}
+
+static char *
+search_for_command(char *filename) {
 	static char pathname[PATH_MAX];
 	char *path;
 	int m, n;
@@ -177,20 +154,42 @@ static char *search_for_command(char *filename)
 	return filename;
 }
 
-char **process_options(int argc, char **argv)
-{
+static void
+guess_cols(void) {
+	struct winsize ws;
+	char *c;
+
+	options.align = DEFAULT_ALIGN;
+	c = getenv("COLUMNS");
+	if (c && *c) {
+		char *endptr;
+		int cols;
+		cols = strtol(c, &endptr, 0);
+		if (cols > 0 && !*endptr) {
+			options.align = cols * 5 / 8;
+		}
+	} else if (ioctl(1, TIOCGWINSZ, &ws) != -1 && ws.ws_col > 0) {
+		options.align = ws.ws_col * 5 / 8;
+	} else if (ioctl(2, TIOCGWINSZ, &ws) != -1 && ws.ws_col > 0) {
+		options.align = ws.ws_col * 5 / 8;
+	}
+}
+
+char **
+process_options(int argc, char **argv) {
 	progname = argv[0];
-	output = stderr;
+	options.output = stderr;
+
+	guess_cols();
 
-#if HAVE_GETOPT || HAVE_GETOPT_LONG
 	while (1) {
 		int c;
-#if HAVE_GETOPT_LONG
+		char *p;
 		int option_index = 0;
 		static struct option long_options[] = {
 			{"align", 1, 0, 'a'},
 			{"config", 1, 0, 'F'},
-			{"debug", 0, 0, 'd'},
+			{"debug", 1, 0, 'D'},
 # ifdef USE_DEMANGLE
 			{"demangle", 0, 0, 'C'},
 #endif
@@ -201,39 +200,40 @@ char **process_options(int argc, char **argv)
 			{"version", 0, 0, 'V'},
 			{0, 0, 0, 0}
 		};
-		c = getopt_long(argc, argv, "+cdfhiLrStTV"
+		c = getopt_long(argc, argv, "+cfhiLrStTV"
 # ifdef USE_DEMANGLE
 				"C"
 # endif
-				"a:A:e:F:l:n:o:p:s:u:x:X:", long_options,
+				"a:A:D:e:F:l:n:o:p:s:u:x:X:", long_options,
 				&option_index);
-#else
-		c = getopt(argc, argv, "+cdfhiLrStTV"
-# ifdef USE_DEMANGLE
-				"C"
-# endif
-				"a:A:e:F:l:n:o:p:s:u:x:X:");
-#endif
 		if (c == -1) {
 			break;
 		}
 		switch (c) {
 		case 'a':
-			opt_a = atoi(optarg);
+			options.align = atoi(optarg);
 			break;
 		case 'A':
-			opt_A = atoi(optarg);
+			options.arraylen = atoi(optarg);
 			break;
 		case 'c':
-			opt_c++;
+			options.summary++;
 			break;
 #ifdef USE_DEMANGLE
 		case 'C':
-			opt_C++;
+			options.demangle++;
 			break;
 #endif
-		case 'd':
-			opt_d++;
+		case 'D':
+			if (optarg[0]=='h') {
+				usage_debug();
+				exit(0);
+			}
+			options.debug = strtoul(optarg,&p,8);
+			if (*p) {
+				fprintf(stderr, "%s: --debug requires an octal argument\n", progname);
+				err_usage();
+			}
 			break;
 		case 'e':
 			{
@@ -269,7 +269,7 @@ char **process_options(int argc, char **argv)
 				break;
 			}
 		case 'f':
-			opt_f = 1;
+			options.follow = 1;
 			break;
 		case 'F':
 			{
@@ -290,31 +290,30 @@ char **process_options(int argc, char **argv)
 			opt_i++;
 			break;
 		case 'l':
-			if (library_num == MAX_LIBRARY) {
+			if (library_num == MAX_LIBRARIES) {
 				fprintf(stderr,
 					"Too many libraries.  Maximum is %i.\n",
-					MAX_LIBRARY);
+					MAX_LIBRARIES);
 				exit(1);
 			}
 			library[library_num++] = optarg;
 			break;
 		case 'L':
-			opt_L = 0;
+			options.libcalls = 0;
 			break;
 		case 'n':
-			opt_n = atoi(optarg);
+			options.indent = atoi(optarg);
 			break;
 		case 'o':
-			opt_o++;
-			output = fopen(optarg, "w");
-			if (!output) {
+			options.output = fopen(optarg, "w");
+			if (!options.output) {
 				fprintf(stderr,
 					"Can't open %s for output: %s\n",
 					optarg, strerror(errno));
 				exit(1);
 			}
-			setvbuf(output, (char *)NULL, _IOLBF, 0);
-			fcntl(fileno(output), F_SETFD, FD_CLOEXEC);
+			setvbuf(options.output, (char *)NULL, _IOLBF, 0);
+			fcntl(fileno(options.output), F_SETFD, FD_CLOEXEC);
 			break;
 		case 'p':
 			{
@@ -332,10 +331,10 @@ char **process_options(int argc, char **argv)
 			opt_r++;
 			break;
 		case 's':
-			opt_s = atoi(optarg);
+			options.strlen = atoi(optarg);
 			break;
 		case 'S':
-			opt_S = 1;
+			options.syscalls = 1;
 			break;
 		case 't':
 			opt_t++;
@@ -344,11 +343,11 @@ char **process_options(int argc, char **argv)
 			opt_T++;
 			break;
 		case 'u':
-			opt_u = optarg;
+			options.user = optarg;
 			break;
 		case 'V':
 			printf("ltrace version " PACKAGE_VERSION ".\n"
-					"Copyright (C) 1997-2008 Juan Cespedes <cespedes@debian.org>.\n"
+					"Copyright (C) 1997-2009 Juan Cespedes <cespedes@debian.org>.\n"
 					"This is free software; see the GNU General Public Licence\n"
 					"version 2 or later for copying conditions.  There is NO warranty.\n");
 			exit(0);
@@ -387,20 +386,11 @@ char **process_options(int argc, char **argv)
 			}
 
 		default:
-#if HAVE_GETOPT_LONG
-			fprintf(stderr,
-				"Try `%s --help' for more information\n",
-				progname);
-#else
-			fprintf(stderr, "Try `%s -h' for more information\n",
-				progname);
-#endif
-			exit(1);
+			err_usage();
 		}
 	}
 	argc -= optind;
 	argv += optind;
-#endif
 
 	if (!opt_F) {
 		opt_F = malloc(sizeof(struct opt_F_t));
@@ -427,13 +417,12 @@ char **process_options(int argc, char **argv)
 
 	if (!opt_p && argc < 1) {
 		fprintf(stderr, "%s: too few arguments\n", progname);
-		usage();
-		exit(1);
+		err_usage();
 	}
 	if (opt_r && opt_t) {
 		fprintf(stderr, "%s: Incompatible options -r and -t\n",
 			progname);
-		exit(1);
+		err_usage();
 	}
 	if (argc > 0) {
 		command = search_for_command(argv[0]);
