@@ -1,26 +1,20 @@
-#if HAVE_CONFIG_H
-#include "config.h"
-#endif
-
 #include <sys/types.h>
 #include <string.h>
 #include <stdio.h>
 #include <errno.h>
 #include <stdlib.h>
 
-#include "ltrace.h"
-#include "options.h"
-#include "elf.h"
+#include "common.h"
 
-struct process *open_program(char *filename, pid_t pid)
-{
-	struct process *proc;
-	proc = calloc(sizeof(struct process), 1);
+Process *
+open_program(char *filename, pid_t pid) {
+	Process *proc;
+	proc = calloc(sizeof(Process), 1);
 	if (!proc) {
 		perror("malloc");
 		exit(1);
 	}
-	proc->filename = filename;
+	proc->filename = strdup(filename);
 	proc->breakpoints_enabled = -1;
 	if (pid) {
 		proc->pid = pid;
@@ -32,9 +26,9 @@ struct process *open_program(char *filename, pid_t pid)
 	return proc;
 }
 
-void open_pid(pid_t pid, int verbose)
-{
-	struct process *proc;
+void
+open_pid(pid_t pid) {
+	Process *proc;
 	char *filename;
 
 	if (trace_pid(pid) < 0) {
@@ -45,16 +39,27 @@ void open_pid(pid_t pid, int verbose)
 
 	filename = pid2name(pid);
 
-#if 0
 	if (!filename) {
-		if (verbose) {
-			fprintf(stderr, "Cannot trace pid %u: %s\n", pid,
+		fprintf(stderr, "Cannot trace pid %u: %s\n", pid,
 				strerror(errno));
-		}
 		return;
 	}
-#endif
 
 	proc = open_program(filename, pid);
+	continue_process(pid);
 	proc->breakpoints_enabled = 1;
 }
+
+Process *
+pid2proc(pid_t pid) {
+	Process *tmp;
+
+	tmp = list_of_processes;
+	while (tmp) {
+		if (pid == tmp->pid) {
+			return tmp;
+		}
+		tmp = tmp->next;
+	}
+	return NULL;
+}
