@@ -1,17 +1,10 @@
-#if HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <sys/time.h>
 
-#include "ltrace.h"
-#include "options.h"
-
-#ifdef USE_DEMANGLE
-#include "demangle.h"
-#endif
+#include "common.h"
 
 static int num_entries = 0;
 static struct entry_st {
@@ -68,28 +61,26 @@ void show_summary(void)
 
 	qsort(entries, num_entries, sizeof(*entries), compar);
 
-	printf("%% time     seconds  usecs/call     calls      function\n");
-	printf
-	    ("------ ----------- ----------- --------- --------------------\n");
+	fprintf(options.output, "%% time     seconds  usecs/call     calls      function\n");
+	fprintf(options.output, "------ ----------- ----------- --------- --------------------\n");
 	for (i = 0; i < num_entries; i++) {
 		unsigned long long int c;
 		unsigned long long int p;
 		c = 1000000 * (int)entries[i].tv.tv_sec +
 		    (int)entries[i].tv.tv_usec;
 		p = 100000 * c / tot_usecs + 5;
-		printf("%3lu.%02lu %4d.%06d %11lu %9d %s\n",
+		fprintf(options.output, "%3lu.%02lu %4d.%06d %11lu %9d %s\n",
 		       (unsigned long int)(p / 1000),
 		       (unsigned long int)((p / 10) % 100),
 		       (int)entries[i].tv.tv_sec, (int)entries[i].tv.tv_usec,
 		       (unsigned long int)(c / entries[i].count),
 		       entries[i].count,
 #ifdef USE_DEMANGLE
-		       opt_C ? my_demangle(entries[i].name) :
+		       options.demangle ? my_demangle(entries[i].name) :
 #endif
 		       entries[i].name);
 	}
-	printf
-	    ("------ ----------- ----------- --------- --------------------\n");
-	printf("100.00 %4lu.%06lu             %9d total\n", tot_usecs / 1000000,
+	fprintf(options.output, "------ ----------- ----------- --------- --------------------\n");
+	fprintf(options.output, "100.00 %4lu.%06lu             %9d total\n", tot_usecs / 1000000,
 	       tot_usecs % 1000000, tot_count);
 }
