@@ -1,6 +1,4 @@
-#if HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <string.h>
 #include <sys/types.h>
@@ -9,7 +7,7 @@
 #include <sys/ptrace.h>
 #include <asm/ptrace.h>
 
-#include "ltrace.h"
+#include "common.h"
 #include "output.h"
 #include "ptrace.h"
 
@@ -26,8 +24,8 @@
 #define off_ip 48
 #define off_pc 60
 
-void get_arch_dep(struct process *proc)
-{
+void
+get_arch_dep(Process *proc) {
 	proc_archdep *a;
 
 	if (!proc->arch_ptr)
@@ -41,8 +39,8 @@ void get_arch_dep(struct process *proc)
  *         3 if arch-specific syscall entry, 4 if arch-specific syscall exit,
  *         -1 on error.
  */
-int syscall_p(struct process *proc, int status, int *sysnum)
-{
+int
+syscall_p(Process *proc, int status, int *sysnum) {
 	if (WIFSTOPPED(status)
 	    && WSTOPSIG(status) == (SIGTRAP | proc->tracesysgood)) {
 		/* get the user's pc (plus 8) */
@@ -78,8 +76,8 @@ int syscall_p(struct process *proc, int status, int *sysnum)
 	return 0;
 }
 
-long gimme_arg(enum tof type, struct process *proc, int arg_num, arg_type_info *info)
-{
+long
+gimme_arg(enum tof type, Process *proc, int arg_num, arg_type_info *info) {
 	proc_archdep *a = (proc_archdep *) proc->arch_ptr;
 
 	if (arg_num == -1) {	/* return value */
@@ -121,8 +119,8 @@ long gimme_arg(enum tof type, struct process *proc, int arg_num, arg_type_info *
 	return 0;
 }
 
-void save_register_args(enum tof type, struct process *proc)
-{
+void
+save_register_args(enum tof type, Process *proc) {
 	proc_archdep *a = (proc_archdep *) proc->arch_ptr;
 	if (a->valid) {
 		if (type == LT_TOF_FUNCTION)
