@@ -1,28 +1,34 @@
-#if HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <sys/ptrace.h>
 #include <string.h>
+
+#include "common.h"
 #include "arch.h"
-#include "options.h"
-#include "output.h"
-#include "debug.h"
 
 static unsigned char break_insn[] = BREAKPOINT_VALUE;
 
 #ifdef ARCH_HAVE_ENABLE_BREAKPOINT
-extern void arch_enable_breakpoint(pid_t, struct breakpoint *);
-void enable_breakpoint(pid_t pid, struct breakpoint *sbp)
-{
+extern void arch_enable_breakpoint(pid_t, Breakpoint *);
+void
+enable_breakpoint(pid_t pid, Breakpoint *sbp) {
+	if (sbp->libsym) {
+		debug(DEBUG_PROCESS, "enable_breakpoint: pid=%d, addr=%p, symbol=%s", pid, sbp->addr, sbp->libsym->name);
+	} else {
+		debug(DEBUG_PROCESS, "enable_breakpoint: pid=%d, addr=%p", pid, sbp->addr);
+	}
 	arch_enable_breakpoint(pid, sbp);
 }
 #else
-void enable_breakpoint(pid_t pid, struct breakpoint *sbp)
-{
+void
+enable_breakpoint(pid_t pid, Breakpoint *sbp) {
 	unsigned int i, j;
 
-	debug(1, "enable_breakpoint(%d,%p)", pid, sbp->addr);
+	if (sbp->libsym) {
+		debug(DEBUG_PROCESS, "enable_breakpoint: pid=%d, addr=%p, symbol=%s", pid, sbp->addr, sbp->libsym->name);
+	} else {
+		debug(DEBUG_PROCESS, "enable_breakpoint: pid=%d, addr=%p", pid, sbp->addr);
+	}
 
 	for (i = 0; i < 1 + ((BREAKPOINT_LENGTH - 1) / sizeof(long)); i++) {
 		long a =
@@ -42,17 +48,26 @@ void enable_breakpoint(pid_t pid, struct breakpoint *sbp)
 #endif				/* ARCH_HAVE_ENABLE_BREAKPOINT */
 
 #ifdef ARCH_HAVE_DISABLE_BREAKPOINT
-extern void arch_disable_breakpoint(pid_t, const struct breakpoint *sbp);
-void disable_breakpoint(pid_t pid, const struct breakpoint *sbp)
-{
+extern void arch_disable_breakpoint(pid_t, const Breakpoint *sbp);
+void
+disable_breakpoint(pid_t pid, const Breakpoint *sbp) {
+	if (sbp->libsym) {
+		debug(DEBUG_PROCESS, "disable_breakpoint: pid=%d, addr=%p, symbol=%s", pid, sbp->addr, sbp->libsym->name);
+	} else {
+		debug(DEBUG_PROCESS, "disable_breakpoint: pid=%d, addr=%p", pid, sbp->addr);
+	}
 	arch_disable_breakpoint(pid, sbp);
 }
 #else
-void disable_breakpoint(pid_t pid, const struct breakpoint *sbp)
-{
+void
+disable_breakpoint(pid_t pid, const Breakpoint *sbp) {
 	unsigned int i, j;
 
-	debug(2, "disable_breakpoint(%d,%p)", pid, sbp->addr);
+	if (sbp->libsym) {
+		debug(DEBUG_PROCESS, "disable_breakpoint: pid=%d, addr=%p, symbol=%s", pid, sbp->addr, sbp->libsym->name);
+	} else {
+		debug(DEBUG_PROCESS, "disable_breakpoint: pid=%d, addr=%p", pid, sbp->addr);
+	}
 
 	for (i = 0; i < 1 + ((BREAKPOINT_LENGTH - 1) / sizeof(long)); i++) {
 		long a =
