@@ -1,12 +1,10 @@
-#if HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <sys/types.h>
 #include <sys/ptrace.h>
 #include <asm/ptrace.h>
 
-#include "ltrace.h"
+#include "common.h"
 
 #if (!defined(PTRACE_PEEKUSER) && defined(PTRACE_PEEKUSR))
 # define PTRACE_PEEKUSER PTRACE_PEEKUSR
@@ -16,22 +14,27 @@
 # define PTRACE_POKEUSER PTRACE_POKEUSR
 #endif
 
-void *get_instruction_pointer(struct process *proc)
-{
+void *
+get_instruction_pointer(Process *proc) {
 	return (void *)ptrace(PTRACE_PEEKUSER, proc->pid, 4 * EIP, 0);
 }
 
-void set_instruction_pointer(struct process *proc, void *addr)
-{
+void
+set_instruction_pointer(Process *proc, void *addr) {
 	ptrace(PTRACE_POKEUSER, proc->pid, 4 * EIP, (long)addr);
 }
 
-void *get_stack_pointer(struct process *proc)
-{
+void *
+get_stack_pointer(Process *proc) {
 	return (void *)ptrace(PTRACE_PEEKUSER, proc->pid, 4 * UESP, 0);
 }
 
-void *get_return_addr(struct process *proc, void *stack_pointer)
-{
+void *
+get_return_addr(Process *proc, void *stack_pointer) {
 	return (void *)ptrace(PTRACE_PEEKTEXT, proc->pid, stack_pointer, 0);
 }
+
+void
+set_return_addr(Process *proc, void *addr) {
+	ptrace(PTRACE_POKETEXT, proc->pid, proc->stack_pointer, (long)addr);
+}
