@@ -1,14 +1,12 @@
 #include <gelf.h>
-#include "ltrace.h"
-#include "elf.h"
-#include "debug.h"
+#include "common.h"
 
 /* A bundle is 128 bits */
 #define BUNDLE_SIZE 16
 
-/* 
+/*
 
-  The PLT has 
+  The PLT has
 
   ] 3 bundles as a header
 
@@ -16,7 +14,7 @@
 
   ] Following that, each PLT entry has it's initial code that the GOT entry
     points to.  Each PLT entry has one bundle allocated.
- 
+
   ] Following that, each PLT entry has two bundles of actual PLT code,
     i.e. load up the address from the GOT and jump to it.  This is the
     point we want to insert the breakpoint, as this will be captured
@@ -24,8 +22,8 @@
 
 */
 
-GElf_Addr arch_plt_sym_val(struct ltelf *lte, size_t ndx, GElf_Rela * rela)
-{
+GElf_Addr
+arch_plt_sym_val(struct ltelf *lte, size_t ndx, GElf_Rela * rela) {
 	/* Find number of entires by removing header and special
 	 * entry, dividing total size by three, since each PLT entry
 	 * will have 3 bundles (1 for inital entry and two for the PLT
@@ -42,7 +40,7 @@ GElf_Addr arch_plt_sym_val(struct ltelf *lte, size_t ndx, GElf_Rela * rela)
 	return addr;
 }
 
-void *sym2addr(struct process *proc, struct library_symbol *sym)
-{
+void *
+sym2addr(Process *proc, struct library_symbol *sym) {
 	return sym->enter_addr;
 }
