@@ -1,6 +1,4 @@
-#if HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -8,7 +6,7 @@
 #include <sys/ptrace.h>
 #include <asm/ptrace.h>
 
-#include "ltrace.h"
+#include "common.h"
 
 #if (!defined(PTRACE_PEEKUSER) && defined(PTRACE_PEEKUSR))
 # define PTRACE_PEEKUSER PTRACE_PEEKUSR
@@ -18,14 +16,14 @@
 # define PTRACE_POKEUSER PTRACE_POKEUSR
 #endif
 
-void get_arch_dep(struct process *proc)
-{
+void
+get_arch_dep(Process *proc) {
 }
 
 /* Returns 1 if syscall, 2 if sysret, 0 otherwise.
  */
-int syscall_p(struct process *proc, int status, int *sysnum)
-{
+int
+syscall_p(Process *proc, int status, int *sysnum) {
 	int depth;
 
 	if (WIFSTOPPED(status)
@@ -36,9 +34,8 @@ int syscall_p(struct process *proc, int status, int *sysnum)
 		if (*sysnum >= 0) {
 			depth = proc->callstack_depth;
 			if (depth > 0 &&
-			    proc->callstack[depth - 1].is_syscall &&
-			    proc->callstack[depth - 1].c_un.syscall ==
-			    *sysnum) {
+					proc->callstack[depth - 1].is_syscall &&
+					proc->callstack[depth - 1].c_un.syscall == *sysnum) {
 				return 2;
 			} else {
 				return 1;
@@ -48,8 +45,8 @@ int syscall_p(struct process *proc, int status, int *sysnum)
 	return 0;
 }
 
-long gimme_arg(enum tof type, struct process *proc, int arg_num)
-{
+long
+gimme_arg(enum tof type, Process *proc, int arg_num, arg_type_info *info) {
 	if (arg_num == -1) {	/* return value */
 		return ptrace(PTRACE_PEEKUSER, proc->pid, 4 * PT_D0, 0);
 	}
@@ -87,6 +84,6 @@ long gimme_arg(enum tof type, struct process *proc, int arg_num)
 	return 0;
 }
 
-void save_register_args(enum tof type, struct process *proc)
-{
+void
+save_register_args(enum tof type, Process *proc) {
 }
