@@ -1,17 +1,13 @@
 #include <gelf.h>
-#include "ltrace.h"
-#include "elf.h"
-#include "debug.h"
-#include "ptrace.h"
-#include "options.h"
+#include "common.h"
 
-GElf_Addr arch_plt_sym_val(struct ltelf *lte, size_t ndx, GElf_Rela * rela)
-{
+GElf_Addr
+arch_plt_sym_val(struct ltelf *lte, size_t ndx, GElf_Rela * rela) {
 	return rela->r_offset;
 }
 
-void *sym2addr(struct process *proc, struct library_symbol *sym)
-{
+void *
+sym2addr(Process *proc, struct library_symbol *sym) {
 	void *addr = sym->enter_addr;
 	long pt_ret;
 
@@ -25,7 +21,7 @@ void *sym2addr(struct process *proc, struct library_symbol *sym)
 		return 0;
 	}
 
-	if (opt_d >= 3) {
+	if (options.debug >= 3) {
 		xinfdump(proc->pid, (void *)(((long)addr-32)&0xfffffff0),
 			 sizeof(void*)*8);
 	}
