@@ -1,6 +1,4 @@
-#if HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -16,10 +14,10 @@
 #define	MAX_DELAY	100000	/* 100000 microseconds = 0.1 seconds */
 
 /*
- * Returns a file name corresponding to a running pid
+ * Returns a (malloc'd) file name corresponding to a running pid
  */
-char *pid2name(pid_t pid)
-{
+char *
+pid2name(pid_t pid) {
 	char proc_exe[1024];
 
 	if (!kill(pid, 0)) {
