@@ -3,15 +3,13 @@
 ** Copyright (C) 2001 IBM Poughkeepsie, IBM Corporation
 */
 
-#if HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <sys/types.h>
 #include <sys/ptrace.h>
 #include <asm/ptrace.h>
 
-#include "ltrace.h"
+#include "common.h"
 
 #if (!defined(PTRACE_PEEKUSER) && defined(PTRACE_PEEKUSR))
 # define PTRACE_PEEKUSER PTRACE_PEEKUSR
@@ -28,8 +26,8 @@
 #define PSW_MASK	0x7fffffff
 #endif
 
-void *get_instruction_pointer(struct process *proc)
-{
+void *
+get_instruction_pointer(Process *proc) {
 	long ret = ptrace(PTRACE_PEEKUSER, proc->pid, PT_PSWADDR, 0) & PSW_MASK;
 #ifdef __s390x__
 	if (proc->mask_32bit)
@@ -38,8 +36,8 @@ void *get_instruction_pointer(struct process *proc)
 	return (void *)ret;
 }
 
-void set_instruction_pointer(struct process *proc, void *addr)
-{
+void
+set_instruction_pointer(Process *proc, void *addr) {
 #ifdef __s390x__
 	if (proc->mask_32bit)
 		addr = (void *)((long)addr & PSW_MASK31);
@@ -47,8 +45,8 @@ void set_instruction_pointer(struct process *proc, void *addr)
 	ptrace(PTRACE_POKEUSER, proc->pid, PT_PSWADDR, addr);
 }
 
-void *get_stack_pointer(struct process *proc)
-{
+void *
+get_stack_pointer(Process *proc) {
 	long ret = ptrace(PTRACE_PEEKUSER, proc->pid, PT_GPR15, 0) & PSW_MASK;
 #ifdef __s390x__
 	if (proc->mask_32bit)
@@ -57,8 +55,8 @@ void *get_stack_pointer(struct process *proc)
 	return (void *)ret;
 }
 
-void *get_return_addr(struct process *proc, void *stack_pointer)
-{
+void *
+get_return_addr(Process *proc, void *stack_pointer) {
 	long ret = ptrace(PTRACE_PEEKUSER, proc->pid, PT_GPR14, 0) & PSW_MASK;
 #ifdef __s390x__
 	if (proc->mask_32bit)
@@ -66,3 +64,12 @@ void *get_return_addr(struct process *proc, void *stack_pointer)
 #endif
 	return (void *)ret;
 }
+
+void
+set_return_addr(Process *proc, void *addr) {
+#ifdef __s390x__
+	if (proc->mask_32bit)
+		addr = (void *)((long)addr & PSW_MASK31);
+#endif
+	ptrace(PTRACE_POKEUSER, proc->pid, PT_GPR14, addr);
+}
