@@ -1,6 +1,4 @@
-#if HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include <sys/types.h>
 #include <sys/wait.h>
@@ -9,7 +7,7 @@
 #include <sys/ptrace.h>
 #include <sys/reg.h>
 
-#include "ltrace.h"
+#include "common.h"
 
 #if (!defined(PTRACE_PEEKUSER) && defined(PTRACE_PEEKUSR))
 # define PTRACE_PEEKUSER PTRACE_PEEKUSR
@@ -19,8 +17,8 @@
 # define PTRACE_POKEUSER PTRACE_POKEUSR
 #endif
 
-void get_arch_dep(struct process *proc)
-{
+void
+get_arch_dep(Process *proc) {
 	unsigned long cs;
 	if (proc->arch_ptr)
 		return;
@@ -34,14 +32,15 @@ void get_arch_dep(struct process *proc)
 
 /* Returns 1 if syscall, 2 if sysret, 0 otherwise.
  */
-int syscall_p(struct process *proc, int status, int *sysnum)
-{
+int
+syscall_p(Process *proc, int status, int *sysnum) {
 	if (WIFSTOPPED(status)
 	    && WSTOPSIG(status) == (SIGTRAP | proc->tracesysgood)) {
 		*sysnum = ptrace(PTRACE_PEEKUSER, proc->pid, 8 * ORIG_RAX, 0);
 
 		if (proc->callstack_depth > 0 &&
-		    proc->callstack[proc->callstack_depth - 1].is_syscall) {
+				proc->callstack[proc->callstack_depth - 1].is_syscall &&
+				proc->callstack[proc->callstack_depth - 1].c_un.syscall == *sysnum) {
 			return 2;
 		}
 
@@ -53,8 +52,7 @@ int syscall_p(struct process *proc, int status, int *sysnum)
 }
 
 static unsigned int
-gimme_arg32(enum tof type, struct process *proc, int arg_num)
-{
+gimme_arg32(enum tof type, Process *proc, int arg_num) {
 	if (arg_num == -1) {	/* return value */
 		return ptrace(PTRACE_PEEKUSER, proc->pid, 8 * RAX, 0);
 	}
@@ -86,8 +84,8 @@ gimme_arg32(enum tof type, struct process *proc, int arg_num)
 	exit(1);
 }
 
-long gimme_arg(enum tof type, struct process *proc, int arg_num, arg_type_info *info)
-{
+long
+gimme_arg(enum tof type, Process *proc, int arg_num, arg_type_info *info) {
 	if (proc->mask_32bit)
 		return (unsigned int)gimme_arg32(type, proc, arg_num);
 
@@ -141,6 +139,6 @@ long gimme_arg(enum tof type, struct process *proc, int arg_num, arg_type_info *
 	return 0;
 }
 
-void save_register_args(enum tof type, struct process *proc)
-{
+void
+save_register_args(enum tof type, Process *proc) {
 }
